@@ -16,7 +16,7 @@ pub enum GitMitConfigError {
     #[error("failed to open git repository {0}")]
     Git2(#[from] git2::Error),
     #[error("{0}")]
-    LintsError(#[from] lints::LintsError),
+    LintsError(#[from] lints::Error),
     #[error(
         "Unrecognised Lint command, only you may only enable or disable, or list available lints"
     )]
@@ -29,8 +29,11 @@ pub enum GitMitConfigError {
     Io(#[from] io::Error),
     #[error("{0}")]
     Vcs(#[from] VcsError),
+    #[cfg(not(target_os = "windows"))]
     #[error("{0}")]
     Xdg(#[from] xdg::BaseDirectoriesError),
     #[error("{0}")]
     Utf8(#[from] std::string::FromUtf8Error),
+    #[error("appdata environment variable missing {0}")]
+    AppDataMissing(#[from] std::env::VarError),
 }
